izug.ticketbox
===============

This Package provides a basic Tracker like Content-Type


Usage
-----

- Add ``izug.ticketbox`` and your the implementation package to your
  buildout configuration:

::

    [instance]
    eggs +=
        izug.ticketbox

- Install the generic setup profiles of those packages.

- Edit any content: on the bottom of the form there is new checkbox "Send
  notification".


Links
-----

- Main github project repository: https://github.com/4teamwork/izug.ticketbox
- Issue tracker: https://github.com/4teamwork/izug.ticketbox/issues
- Package on pypi: http://pypi.python.org/pypi/izug.ticketbox


Maintainer
==========

This package is produced and maintained by `4teamwork <http://www.4teamwork.ch/>`_ company.

